"""Basic tests for optik package."""

import pytest


def test_import():
    """Test that optik can be imported."""
    from optik import Optik
    assert Optik is not None


def test_methods_import():
    """Test that analysis methods can be imported."""
    from optik.methods import DetectionFlow, CounterfactualProbe, GridCellTrace
    assert DetectionFlow is not None
    assert CounterfactualProbe is not None
    assert GridCellTrace is not None


def test_reports_import():
    """Test that reports module can be imported."""
    from optik.reports import ReportGenerator
    assert ReportGenerator is not None


def test_utils_import():
    """Test that utils can be imported."""
    from optik.utils import load_image, save_image, create_detection_overlay
    assert load_image is not None
    assert save_image is not None
    assert create_detection_overlay is not None


def test_version():
    """Test that version is defined."""
    from optik import __version__
    assert __version__ is not None
    assert isinstance(__version__, str)
