"""Methods module - analysis methods for model interpretability."""

from .detection_flow import DetectionFlow
from .counterfactual import CounterfactualProbe
from .grid_trace import GridCellTrace

__all__ = ["DetectionFlow", "CounterfactualProbe", "GridCellTrace"]
