"""Core module - base classes and utilities."""

from .base import BaseModelAdapter
from .hooks import ActivationHook, GradientHook
from .features import FeatureExtractor

__all__ = ["BaseModelAdapter", "ActivationHook", "GradientHook", "FeatureExtractor"]
