from setuptools import setup, find_packages

setup(
    name="optik-vision",
    version="0.1.0",
    description="The optical lens for AI model interpretability",
    author="optik",
    packages=find_packages(),
    python_requires=">=3.9",
    install_requires=[
        "torch>=2.0.0,<2.9.0",  # 2.9-2.10 has c10.dll issues on Windows
        "numpy>=1.20.0",
        "Pillow>=9.0.0",
        "ultralytics>=8.0.0",
        "jinja2>=3.0.0",
    ],
    extras_require={
        "dev": ["pytest", "black", "ruff"],
    },
)
